@@ -3,10 +3,11 @@
 
 import distutils.util
 import os
-from typing import Dict, List, Optional, Set  # noqa: F401
+from typing import Any, Callable, Dict, List, Optional, Set  # noqa: F401
 
 import boto3
 from amundsen_gremlin.config import LocalGremlinConfig
+from flask import Flask  # noqa: F401
 
 from metadata_service.entity.badge import Badge
 
@@ -23,7 +24,12 @@ PROXY_CLIENT_KWARGS = 'PROXY_CLIENT_KWARGS'
 PROXY_CLIENTS = {
     'NEO4J': 'metadata_service.proxy.neo4j_proxy.Neo4jProxy',
     'ATLAS': 'metadata_service.proxy.atlas_proxy.AtlasProxy',
-    'NEPTUNE': 'metadata_service.proxy.neptune_proxy.NeptuneGremlinProxy'
+    'NEPTUNE': 'metadata_service.proxy.neptune_proxy.NeptuneGremlinProxy',
+    'MYSQL': 'metadata_service.proxy.mysql_proxy.MySQLProxy'
+}
+
+PROXY_CLIS = {
+    'MYSQL': 'metadata_service.cli.rds_command.rds_cli'
 }
 
 IS_STATSD_ON = 'IS_STATSD_ON'
@@ -64,7 +70,7 @@ class Config:
 
     USER_DETAIL_METHOD = None   # type: Optional[function]
 
-    RESOURCE_REPORT_CLIENT = None   # type: Optional[function]
+    RESOURCE_REPORT_CLIENT = None  # type: Optional[function]
 
     # On User detail method, these keys will be added into amundsen_common.models.user.User.other_key_values
     USER_OTHER_KEYS = {'mode_user_id'}  # type: Set[str]
@@ -79,6 +85,9 @@ class Config:
     # or num of retries
     PROXY_CLIENT_KWARGS: Dict = dict()
 
+    # Initialize custom flask extensions and routes
+    INIT_CUSTOM_EXT_AND_ROUTES = None  # type: Callable[[Flask], None]
+
     SWAGGER_TEMPLATE_PATH = os.path.join('api', 'swagger_doc', 'template.yml')
     SWAGGER = {
         'openapi': '3.0.2',
@@ -123,7 +132,8 @@ class NeptuneConfig(LocalGremlinConfig, LocalConfig):
     LOG_LEVEL = 'INFO'
 
     # PROXY_HOST FORMAT: wss://<NEPTUNE_URL>:<NEPTUNE_PORT>/gremlin
-    PROXY_PORT = None   # type: ignore
+    PROXY_HOST = os.environ.get('PROXY_HOST', 'localhost')
+    PROXY_PORT = None  # type: ignore
 
     PROXY_CLIENT = PROXY_CLIENTS['NEPTUNE']
     PROXY_PASSWORD = boto3.session.Session(region_name=os.environ.get('AWS_REGION', 'us-east-1'))
@@ -134,3 +144,21 @@ class NeptuneConfig(LocalGremlinConfig, LocalConfig):
     }
 
     JANUS_GRAPH_URL = None
+
+
+class MySQLConfig(LocalConfig):
+    PROXY_CLIENT = PROXY_CLIENTS['MYSQL']
+    PROXY_CLI = PROXY_CLIS['MYSQL']
+
+    PROXY_HOST = None   # type: ignore
+    PROXY_PORT = None   # type: ignore
+    PROXY_USER = None   # type: ignore
+    PROXY_PASSWORD = None   # type: ignore
+
+    SQLALCHEMY_DATABASE_URI = os.environ.get('SQLALCHEMY_DATABASE_URI', 'mysql://user:password@127.0.0.1:3306/amundsen')
+    PROXY_CLIENT_KWARGS: Dict[str, Any] = {
+        'echo': bool(distutils.util.strtobool(os.environ.get('ECHO', 'False'))),
+        'pool_size': os.environ.get('POOL_SIZE', 5),
+        'max_overflow': os.environ.get('MAX_OVERFLOW', 10),
+        'connect_args': dict()
+    }
